'
' Copyright (c) 2001-2010 by PDFTron Systems Inc. All Rights Reserved.
'

Imports System

Imports pdftron
Imports pdftron.Common
Imports pdftron.Filters
Imports pdftron.SDF
Imports pdftron.PDF


Module Module1

    Sub Main()

        PDFNet.Initialize()

		' Relative path to the folder containing test files.
		Dim input_path As String = "../../../TestFiles/"
		Dim output_path As String = "../../../TestFiles/Output/"

		Try
			'---------------------------------------------------------------------------------
			' Sample 1 - Delete every second page

			Console.WriteLine("_______________________________________________")
			Console.WriteLine("Sample 1 - Delete every second page...")
			Console.WriteLine("Opening the input pdf...")

			Dim in_doc As PDFDoc = New PDFDoc(input_path + "newsletter.pdf")
			in_doc.InitSecurityHandler()

			Dim page_num As Integer = in_doc.GetPageCount()
			Dim itr As PageIterator

			While page_num >= 1
                itr = in_doc.GetPageIterator(page_num)
				in_doc.PageRemove(itr)
				page_num -= 2
			End While

			in_doc.Save(output_path + "newsletter_page_remove.pdf", 0)
			Console.WriteLine("Done. Result saved in newsletter_page_remove.pdf...")
			in_doc.Close()


			'---------------------------------------------------------------------------------
			' Sample 2 - Import the entire document

			Console.WriteLine("_______________________________________________")
			Console.WriteLine("Sample 2 - Import the entire document...")
			Console.WriteLine("Opening the input pdf...")
			Dim new_doc As PDFDoc = New PDFDoc
			Dim in_doc2 As PDFDoc = New PDFDoc(input_path + "newsletter.pdf")
			in_doc2.InitSecurityHandler()

			Dim new_cos_doc As SDFDoc = new_doc.GetSDFDoc()
			Dim new_root As Obj = new_cos_doc.ImportObj(in_doc2.GetTrailer().Get("Root").Value(), True)
			new_cos_doc.GetTrailer().Put("Root", new_root)
			new_doc.Save(output_path + "newsletter_doc_copy.pdf", 0)
			Console.WriteLine("Done. Result saved in newsletter_doc_copy.pdf...")

			in_doc2.Close()
			new_doc.Close()

			'---------------------------------------------------------------------------------
			' Sample 3 - Import pages in reverse order

			Console.WriteLine("_______________________________________________")
			Console.WriteLine("Sample 3 - Import pages in reverse order...")
			Console.WriteLine("Opening the input pdf...")

			Dim in_doc3 As PDFDoc = New PDFDoc(input_path + "newsletter.pdf")
			in_doc3.InitSecurityHandler()

			Dim new_doc3 As PDFDoc = New PDFDoc

			Dim page_num3 As Integer = in_doc3.GetPageCount()
            Dim src_page As PageIterator = in_doc3.GetPageIterator()
			Dim i As Integer
			For i = 0 To page_num3 - 1
				new_doc3.PagePushFront(src_page.Current())
				src_page.Next()
			Next i

			new_doc3.Save(output_path + "newsletter_reverse_pages.pdf", 0)
			Console.WriteLine("Done. Result saved in newsletter_reverse_pages.pdf...")

			in_doc3.Close()
			new_doc3.Close()

			'---------------------------------------------------------------------------------
			' Sample 4 - Inserts a page from one document at different 
			' locations within another document
			Console.WriteLine("_______________________________________________")
			Console.WriteLine("Sample 4 - Insert a page at different locations...")
			Console.WriteLine("Opening the input pdf...")

			Dim in1_doc As PDFDoc = New PDFDoc(input_path + "newsletter.pdf")
			in1_doc.InitSecurityHandler()

			Dim in2_doc As PDFDoc = New PDFDoc(input_path + "fish.pdf")
			in2_doc.InitSecurityHandler()

            Dim src_page4 As Page = in2_doc.GetPage(1) ' Get the first page
			Dim page_num4 As Integer = in1_doc.GetPageCount()
			Dim i4 As Integer
			For i4 = 1 To page_num4 - 1 Step 3
                Dim it As PageIterator = in1_doc.GetPageIterator(i4)
                in1_doc.PageInsert(it, src_page4)
			Next i4

			in1_doc.Save(output_path + "newsletter_page_insert.pdf", 0)
			Console.WriteLine("Done. Result saved in newsletter_page_insert.pdf...")

			in1_doc.Close()
			in2_doc.Close()

			'---------------------------------------------------------------------------------
			' Sample 5 - Replicate pages within a single document

			Console.WriteLine("_______________________________________________")
			Console.WriteLine("Sample 5 - Replicate pages within a single document...")
			Console.WriteLine("Opening the input pdf...")
			Dim doc5 As PDFDoc = New PDFDoc(input_path + "newsletter.pdf")
			doc5.InitSecurityHandler()

			' Replicate the cover page three times (copy page #1 and place it before the 
			' seventh page in the document page sequence)
            Dim cover As Page = doc5.GetPage(1)
            doc5.PageInsert(doc5.GetPageIterator(7), cover)
            doc5.PageInsert(doc5.GetPageIterator(7), cover)
            doc5.PageInsert(doc5.GetPageIterator(7), cover)

			' Replicate the cover page two more times by placing it before and after
			' existing pages.
			doc5.PagePushFront(cover)
			doc5.PagePushBack(cover)

			doc5.Save(output_path + "newsletter_page_clone.pdf", 0)
			Console.WriteLine("Done. Result saved in newsletter_page_clone...")

			doc5.Close()

			'---------------------------------------------------------------------------------
			' Sample 6 - Use ImportPages() in order to copy multiple pages at once 
			' in order to preserve shared resources between pages (e.g. images, fonts, 
			' colorspaces, etc.)
			Console.WriteLine("_______________________________________________")
			Console.WriteLine("Sample 6 - Preserving shared resources using ImportPages...")
			Console.WriteLine("Opening the input pdf...")
			Dim in_doc6 As PDFDoc = New PDFDoc(input_path + "newsletter.pdf")
			in_doc6.InitSecurityHandler()

			Dim new_doc6 As PDFDoc = New PDFDoc

			Dim copy_pages As ArrayList = New ArrayList
            Dim itr6 As PageIterator = in_doc6.GetPageIterator()
            While itr6.HasNext()
                copy_pages.Add(itr6.Current())
                itr6.Next()
            End While

            Dim imported_pages As ArrayList = new_doc6.ImportPages(copy_pages)
            Dim i6 As Integer
            For i6 = 0 To imported_pages.Count - 1
                new_doc6.PagePushFront(imported_pages(i6))    ' Order pages in reverse order. 
                ' Use PagePushBack() if you would like to preserve the same order.
            Next i6

            new_doc6.Save(output_path + "newsletter_import_pages.pdf", 0)
            Console.WriteLine("Done. Result saved in newsletter_import_pages.pdf...")
            Console.WriteLine()
            Console.WriteLine("Note that the output file size is less than half the size")
            Console.WriteLine("of the file produced using individual page copy operations")
            Console.WriteLine("between two documents (as in Sample 3)")

            in_doc6.Close()
            new_doc6.Close()


        Catch ex As PDFNetException
			Console.WriteLine(ex.Message)
		Catch ex As Exception
			MsgBox(ex.Message)
		End Try

		PDFNet.Terminate()
	End Sub
End Module
